@@ -1,7 +1,8 @@
 import os
-import pmock
 import unittest
 
+import mock
+
 from TestBase import TestBase
 from RepositorySimulator import PooledRepository, NonPooledRepository
 
@@ -16,7 +17,7 @@ from debpartial_mirror import Failures
 class EndToEndTests(TestBase):
 	def setUp(self):
 		TestBase.setUp(self)
-		self.mockCommandExecutor = self.mock()
+		self.mockCommandExecutor = mock.Mock()
 		Dists.Dists._commandExecutor = self.mockCommandExecutor.execute
 
 
@@ -120,6 +121,30 @@ server = file://%s
 		self.checkPackages([], mirroredRepository, distribution="sid", component="main", architecture="i386")
 
 
+	def test01e(self):
+		""" Mirror a pooled repository - same package in multiple archs"""
+		sourceRepository = PooledRepository()
+		self.addPackages(sourceRepository, ["package1"], distribution="etch", component="main", architecture="i386")
+		self.addPackages(sourceRepository, ["package1", "package3"], distribution="etch", component="main", architecture="arm")
+		self.addPackages(sourceRepository, ["package2"], distribution="etch", component="main", architecture="alpha")
+		sourceDir = self.writeRepository(sourceRepository)
+
+		globalConfiguration, mirrorDir = self.createGlobalConfiguration(
+			architectures = "i386 arm",
+		)
+		configuration = self.loadConfiguration(globalConfiguration + """
+[myRepo]
+server = file://%s
+"""% sourceDir)
+
+		self.doAll(configuration)
+
+		mirroredRepository = self.readMirror(PooledRepository, mirrorDir,multi=True)
+		self.checkPackages(["package1"], mirroredRepository, distribution="etch", component="main", architecture="i386")
+		self.checkPackages([], mirroredRepository, distribution="etch", component="main", architecture="alpha")
+		self.checkPackages(["package1", "package3"], mirroredRepository, distribution="etch", component="main", architecture="arm")
+
+
 	def test02a(self):
 		""" Mirror a pooled repository - filters """
 		sourceRepository = PooledRepository()
@@ -219,6 +244,42 @@ standalone = true
 			self.failUnlessEqual("required1 needs [depends2,depends4]", ex.format())
 
 
+	def test02e(self):
+		""" Mirror a pooled repository - filters with architecture specific dependencies"""
+		sourceRepository = PooledRepository()
+		packageList1 = self.addPackages(sourceRepository,
+			["depends1",],
+			distribution="etch", component="main", architecture="i386"
+		)
+		packageList2 = self.addPackages(sourceRepository,
+			["depends2",],
+			distribution="etch", component="main", architecture="arm"
+		)
+		packageList1.addPackage("required1", Depends="depends1")
+		packageList2.addPackage("required2", Depends="depends2")
+		sourceDir = self.writeRepository(sourceRepository)
+		globalConfiguration, mirrorDir = self.createGlobalConfiguration(architectures="i386 arm")
+		configuration = self.loadConfiguration(globalConfiguration + """
+[myRepo]
+server = file://%s
+filter = name:required.* exclude-name:.*Excluded
+
+"""%  sourceDir)
+
+		self.doAll(configuration)
+
+		mirroredRepository = self.readMirror(PooledRepository, mirrorDir, multi=True)
+		self.checkPackages(
+			["required1", "depends1"],
+			mirroredRepository,
+			distribution="etch", component="main", architecture="i386"
+		)
+		self.checkPackages(
+			["required2", "depends2"],
+			mirroredRepository,
+			distribution="etch", component="main", architecture="arm"
+		)
+
 	def test03a(self):
 		""" Mirror a source repositroy - basic """
 		sourceRepository = PooledRepository()
@@ -316,13 +377,11 @@ backends = src1 src2
 signature_key = default
 """% (sourceDir1, sourceDir2))
 
-		self.mockCommandExecutor.expects(pmock.once()).execute(
-			pmock.eq("gpg -abs  -o - %s/myRepo/dists/myRepo/Release > %s/myRepo/dists/myRepo/Release.gpg" % (
-			mirrorDir, mirrorDir)
-		)).will(pmock.return_value(0))
-
+		self.mockCommandExecutor.execute.return_value = 0
 		self.doAll(configuration)
-
+		self.mockCommandExecutor.execute.assert_called_with(
+			"gpg -abs  -o - %s/myRepo/dists/myRepo/Release > %s/myRepo/dists/myRepo/Release.gpg" % (mirrorDir, mirrorDir)
+		)
 		mergedRepository = self.readMirror(PooledRepository, mirrorDir)
 		self.checkPackages(
 			["A", "B", "C", "D"],
@@ -355,12 +414,11 @@ backends = src1 src2
 signature_key = DEADBEEF
 """% (sourceDir1, sourceDir2))
 
-		self.mockCommandExecutor.expects(pmock.once()).execute(
-			pmock.eq("gpg -abs -u DEADBEEF -o - %s/myRepo/dists/myRepo/Release > %s/myRepo/dists/myRepo/Release.gpg" % (
-			mirrorDir, mirrorDir)
-		)).will(pmock.return_value(0))
+		self.mockCommandExecutor.execute.return_value = 0
 		self.doAll(configuration)
-
+		self.mockCommandExecutor.execute.assert_called_with(
+			"gpg -abs -u DEADBEEF -o - %s/myRepo/dists/myRepo/Release > %s/myRepo/dists/myRepo/Release.gpg" % (mirrorDir, mirrorDir)
+		)
 		mergedRepository = self.readMirror(PooledRepository, mirrorDir)
 		self.checkInstallerPackages(
 			["udebA", "udebB", "udebC", "udebD"],
@@ -568,7 +626,7 @@ server = file://%s
 
 	def test08a(self):
 		""" Dependency resolution from another repository (resolve_deps_using) """
-		sourceRepository = PooledRepository()
+		sourceRepository = PooledRepository(missingReleaseFields=("Version",))
 		packageList = self.addPackages(sourceRepository, ["pack1", "pack2",], distribution="etch")
 		packageList.addPackage("pack3", Depends="dep1, dep2")
 		depRepository = PooledRepository()
@@ -587,14 +645,12 @@ resolve_deps_using = dep
 signature_key = default
 """% (depDir, sourceDir))
 
-		self.mockCommandExecutor.expects(pmock.once()).execute(
-			pmock.eq("gpg -abs  -o - %s/myRepo/dists/etch/Release > %s/myRepo/dists/etch/Release.gpg" % (
-			mirrorDir, mirrorDir)
-		)).will(pmock.return_value(0))
-
+		self.mockCommandExecutor.execute.return_value = 0
 		self.doAll(configuration)
+		self.mockCommandExecutor.execute.assert_called_with(
+			"gpg -abs  -o - %s/myRepo/dists/etch/Release > %s/myRepo/dists/etch/Release.gpg" % (mirrorDir, mirrorDir)
+		)
 
-		print "*****",mirrorDir
 		myRepository = self.readMirror(PooledRepository, mirrorDir)
 		self.checkPackages(
 			["pack1", "pack2", "pack3", "dep1", "dep2"],
